﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using System.Net;
using System.IO;

using System.Web; //Add reference to System.Web
using System.Runtime.Serialization.Json; //Add reference to System.Runtime.Serialization

namespace RedCritterConnecter.Samples
{
    //Create a class to contain the response

    public class GetUserProfileByEmailResponse
    {
        public Int64 UserID { get; set; }
        public String FirstName { get; set; }
        public String LastName { get; set; }
        public Boolean Result { get; set; }
        public List<AppItem> Apps { get; set; }
    }

    public class AppItem
    {
        public String AppName { get; set; }
        public Int64 AppID { get; set; }
    }

    public class GetUserProfileByEmail
    {

        public delegate void OnGetUserProfileByEmailResponse(GetUserProfileByEmailResponse GetUserProfileByEmailResponse);
        public event OnGetUserProfileByEmailResponse onGetUserProfileByEmailResponse;

        public delegate void OnGetUserProfileByEmailResponseError(GetUserProfileByEmailResponse GetUserProfileByEmailResponse);
        public event OnGetUserProfileByEmailResponseError onGetUserProfileByEmailResponseError;

        const string CONST_ConnecterBaseURL = "https://www.redcritterconnecter.com/";

        public void Execute(String Email)
        {
            try
            {
                //Create url encoded parameters in query string
                String queryString = "email=" + System.Web.HttpUtility.UrlEncode(Email);

                //Create a new instance of a WebClient
                WebClient wc = new System.Net.WebClient();

                //Prevent this request from caching in order to ensure that it is sent to server
                wc.CachePolicy = new System.Net.Cache.RequestCachePolicy(System.Net.Cache.RequestCacheLevel.NoCacheNoStore);

                //Attach an event handler to receive the response
                wc.DownloadStringCompleted += onGetUserProfileByEmailResponseReceived;

                //Make the call
                            
                wc.DownloadStringAsync(new Uri(CONST_ConnecterBaseURL + "services/gamificationv1/GetUserProfileByEmail?" + queryString, UriKind.Absolute));
            }
            catch
            {
                //Something went wrong communicating with the server
                if (onGetUserProfileByEmailResponseError != null)
                {
                    onGetUserProfileByEmailResponseError(null);
                }
            }

        }

        private void onGetUserProfileByEmailResponseReceived(object sender, DownloadStringCompletedEventArgs e)
        {
            try
            {
                //Create a JSON serializer
                System.Runtime.Serialization.Json.DataContractJsonSerializer s = new DataContractJsonSerializer(typeof(GetUserProfileByEmailResponse));
               

                //Copy the string into a memory stream
                MemoryStream ms = new MemoryStream(Encoding.UTF8.GetBytes(e.Result));

                //Read the stream into an object matching the response's type
                GetUserProfileByEmailResponse GetUserProfileByEmailResponse = (GetUserProfileByEmailResponse)s.ReadObject(ms);

                //Work with the populated response object
                if (GetUserProfileByEmailResponse.Result == true)
                {
                    //Request was accepted, raise the success event
                    onGetUserProfileByEmailResponse(GetUserProfileByEmailResponse);
                }
                else
                {
                    //Something went wrong
                    if (onGetUserProfileByEmailResponseError != null)
                    {
                        //Request failed, raise the error event
                        onGetUserProfileByEmailResponseError(GetUserProfileByEmailResponse);
                    }
                }
            }
            catch
            {
                //Something went wrong
                onGetUserProfileByEmailResponseError(null);
            }
        }
    }
}
